/*****************************************************************************
  klocate -- a KDE front-end to slocate
  version 0.50.3, March 7, 2004                                                              
  Programmed by: Alexandre Oberlin                              
  Report any Bugs to: alxobr@free.fr   
  Thanks to Kevin Lindsay for programming slocate.                                                                                                                                      
     Copyright (C) version Free Software Foundation, Inc.                       
     This program is free software; you can redistribute it and/or modify    
     it under the terms of the GNU General Public License as published by    
     the Free Software Foundation; either version 2, or (at your option)     
     any later version.                                                      
     This program is distributed in the hope that it will be useful,         
     but WITHOUT ANY WARRANTY; without even the implied warranty of          
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           
     GNU General Public License for more details.                            
     You should have received a copy of the GNU General Public License       
     along with this program; if not, write to the Free Software             
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.               
*****************************************************************************/
/****************************************************************
** loccmd.cpp
** Implementation of LocCmd class
****************************************************************/
#include <klocale.h>
#include "defines.h"
#include "loccmd.h"
#include "topwidget.h"
LocCmd::LocCmd( QWidget *parent, bool _storehistory, const char *name )
  : QWidget( parent, name ), storehistory (_storehistory)
{
    le = new KHistoryCombo(false, this, "le");
      if (storehistory)
    {
      kapp->config()->setGroup ("Options");
      le->setHistoryItems(kapp->config()->readListEntry ("history")) ;
      }
    le->setMaxCount(8);
    QToolTip::add( le, i18n("Enter here the string or regexp you want to search for") );
    cb = new QCheckBox (i18n("Case sensitive"), this); 
    cb->setChecked (false); 
    QToolTip::add( cb, i18n("Check this if you want exact case matches only") );
    cb2 = new QCheckBox (i18n("Spare listing"), this); 
    cb2->setChecked (true); 
    QToolTip::add( cb2, i18n("Check this to avoid listing non matching contents of matching directories"));
    cb3 = new QCheckBox (i18n("Regexp search"), this); 
    cb3->setChecked (false); 
    QToolTip::add( cb3, i18n("Check this to consider the string above as a regexp pattern") );
    search_pb  = new QPushButton(i18n("&Search"), this, "search_pb"  );
    QToolTip::add( search_pb, i18n("Launch the search on selected volumes") );
    connect( le, SIGNAL(returnPressed ()),  search_pb, SIGNAL(clicked()));
    connect( search_pb, SIGNAL(clicked()), SLOT(start() ));
  stopit= FALSE;
    QVBoxLayout *loc = new QVBoxLayout( this );
  loc->addWidget( le);
  loc->addSpacing( DIALOG_MARGIN);
  loc->addWidget( cb);
  loc->addWidget( cb2);
  loc->addWidget( cb3);
  loc->addSpacing( DIALOG_MARGIN);
  loc->addWidget( search_pb);
  loc->addStretch( 10 );
  setMaximumWidth(kapp->mainWidget()->width()/3);  
  setFocusProxy( le );
  runflag=false;
}
LocCmd::~LocCmd()
{
  kapp->config()->setGroup ("Options");
  if (storehistory)
    {
      kapp->config()->writeEntry ("storeHistory", "TRUE");  
      kapp->config()->writeEntry ( "history", le->historyItems());
    }
  else
    {
      kapp->config()->writeEntry ("storeHistory", "FALSE"); 
      kapp->config()->writeEntry ( "history", "");
    }
}
const QString  LocCmd::value() 
{
  return le->currentText();
}
void LocCmd::remember()
{
  if (le->historyItems().contains(le->currentText()) == 0 )
   le->addToHistory(le->currentText());
}
void LocCmd::start()
{
if (runflag) 
  {
  stopit=TRUE;
  }
else
  {
  enableStop(); 
  emit search();
  }
}
void LocCmd::enableStop()
{
  runflag=true;
  search_pb->setText(i18n("A&bort"));
  search_pb->repaint();
}
void LocCmd::enableStart()
{
  runflag=false;
  search_pb->setText(i18n("&Search"));
  search_pb->repaint();
}
