/****************************************************************
**
** Implementation of SelButtonGroup, SelButton
** 
****************************************************************/
#include "selbutton.h"
#include <qcursor.h> 
#include <qregexp.h> 
#include "topwidget.h"
#include <klocale.h> 
extern TopWidget * tw;
/**************************************************************************
******************************* SelButton *******************************
**************************************************************************/
SelButton::SelButton( QWidget *parent,  QStringList _seltoplay, char * name)
  : QPushButton( (QString)name, parent, name), seltoplay (_seltoplay)
{
  setFocusPolicy(QWidget::StrongFocus);
  setText(i18n("(void)"));
}
SelButton::~SelButton()
    {
    }
void SelButton::mousePressEvent ( QMouseEvent * e ) 
{
  if (e->button() == Qt::RightButton)
    {
      cmContextMenu();
    }
  QPushButton::mousePressEvent(e);
}
void SelButton::mouseReleaseEvent( QMouseEvent *e)
{
  if (e->button() == Qt::LeftButton)
    {
      if (e->state() & ( Qt::ShiftButton | Qt::ControlButton))
	{
	  emit addToSel();
	}
      else
	{
	  emit setSel();
	}
    }
  QPushButton::mouseReleaseEvent(e);
}
void SelButton::cmContextMenu()
{
    QPopupMenu *cmenu = new QPopupMenu( this );
#if defined(_QT3_)
    Q_CHECK_PTR( cmenu );  
#endif
    int applyID =  cmenu->insertItem( i18n("&Apply preset"), this, SIGNAL(setSel()));
    int mergeID =  cmenu->insertItem( i18n("&Merge preset"), this, SIGNAL(addToSel()));
    cmenu->insertItem( i18n("&Get preset from volume list"), this, SIGNAL(getSel()));
if
#if defined(KDE3)
  (seltoplay.empty())
#else  
    (seltoplay.isEmpty())
#endif
  {
    cmenu->setItemEnabled(applyID, false);
    cmenu->setItemEnabled(mergeID, false);
  }
 cmenu->exec(QCursor::pos());
 delete cmenu;
}
/***********************************************************************
*************************** SelButtonGroup ****************************
***********************************************************************/
SelButtonGroup::SelButtonGroup( QWidget *parent,  int _nbbuttons, int nbcolumns, const char * title, VolumeList * ll ) : QButtonGroup(nbcolumns, Qt::Horizontal, title, parent), nbbuttons (_nbbuttons)
{
  entries = ll->entries;
  effnbbuttons=0;
  int i;
  SelButton* butt;
  for (i = 0 ; i < nbbuttons; i++)
    {
      butt = new SelButton(this, QStringList());
      connect (butt, SIGNAL(setSel()), this, SLOT(buttonSetSel()));
      connect (butt, SIGNAL(addToSel()), this, SLOT(buttonAddToSel()));
      connect (butt, SIGNAL(getSel()), this, SLOT(buttonGetSel()));
    }
 read_presets();
}
SelButtonGroup::~SelButtonGroup()
{
  write_presets();
}
void SelButtonGroup::rementry(QString oldname)
{
  for (int i =0; i < nbbuttons; i++)
    ((SelButton*)find(i))->seltoplay.remove(oldname);
}
void SelButtonGroup::buttonSetSel()
{
  SelButton * demander = (SelButton *)sender();
  tw->cur_preset=demander->seltoplay;
  emit setSel();  
}
void SelButtonGroup::buttonAddToSel()
{
  SelButton * demander = (SelButton *)sender();
  tw->cur_preset=demander->seltoplay;
   emit addToSel(); 
}
void SelButtonGroup::buttonGetSel()
{
  SelButton * demander = (SelButton *)sender();
  VolumeList * vl = tw->labellist;
  bool noselection = true;
#if defined(KDE3)
  bool nopresel = (demander->seltoplay.empty());
#else  
  bool nopresel =(demander->seltoplay.isEmpty());
#endif
  uint i;
  for (i = 0; i < vl->count(); i++)
    if (vl->isSelected(i)) 
      {
	noselection = false;
	break;
      }
  if (noselection)
    {
      if (nopresel)	
	return;
      if (KMessageBox::warningContinueCancel
	  (parentWidget(), 
	   i18n("Nothing is selected in the volume list") + "\n" + 
	   i18n("Are you sure you want to remove all selection associated with this preset button?"),
	   i18n("Confirmation"), i18n("Yes"))
	  ==  KMessageBox::Cancel)
	{
	  KMessageBox::information(parentWidget(), i18n("Preset button unchanged."),  i18n("Report"));
	  return;
	}
    }
  demander->seltoplay.clear();
  if (noselection)
    {
      demander->setText(i18n("(void)"));
      return ;
    }
  for (i = 0; i < vl->count(); i++)
    if (vl->isSelected(i)) 
      {
	demander->seltoplay.append(vl->entries[i]->filename);
      }
  GuessGetString * gnc;
  QString propose;
  if (nopresel)
    propose = QString("Preset%1").arg(id(demander));
  else
    propose = demander->text();
  gnc = new GuessGetString(this, propose, i18n("Enter new label for preset:"));
  if ( gnc->exec() ) 
    {
      demander->setText(gnc->le->text().stripWhiteSpace());
    }
      delete gnc;
}
int SelButtonGroup::read_presets()
{
  int nb_entries = 0;
  QString strvalue, label_value;
  SelButton* butt;
  kapp->config()->setGroup ("Presets");
  for (int i = 0; i < nbbuttons ; i++)
    {
      butt = (SelButton*)find(i);
      strvalue = kapp->config()->readEntry( QString("preset%1").arg(i));
      label_value = kapp->config()->readEntry( QString("preset%1_label").arg(i));
      if (! strvalue.isEmpty())
	{ 
	  nb_entries++;
	  butt->seltoplay = QStringList::split(" ", strvalue, false);
	  butt->setText(label_value);
	}
    }
  return nb_entries;
}
int SelButtonGroup::write_presets()
{
  int nb_entries = 0;
  QString strvalue;
  SelButton* butt;
  kapp->config()->setGroup ("Presets");
  for (int i = 0; i < nbbuttons ; i++)
    {
      butt = (SelButton*)find(i);
	  nb_entries++;
	  strvalue = butt->seltoplay.join (" "); 
	  kapp->config()->writeEntry( QString("preset%1").arg(i), strvalue);
	  kapp->config()->writeEntry( QString("preset%1_label").arg(i), butt->text());
    }
  return nb_entries;
}
